@@ -22,6 +22,11 @@ VAR="var/lib/$FBDIR"
 CLIENT_SO_VER=2
 UTIL_SO_VER=
 
+if echo ${DEB_BUILD_OPTIONS:-} | egrep -q '\bnodoc\b'; then
+    NODOC="nodoc"
+else
+    NODOC=
+fi
 
 copy ()
 {
@@ -91,7 +96,7 @@ make_server_core () {
     install -m 0755 "$S/intl/libfbintl.so" "$D/$ULFB/intl/"
 
     ln -s "/etc/$FBDIR/fbintl.conf" "$D/$ULFB/intl/"
-    for f in firebird databases fbtrace plugins; do
+    for f in firebird plugins; do
         ln -s "/etc/$FBDIR/$f.conf" "$D/$ULFB/"
     done
 
@@ -112,6 +117,7 @@ make_server () {
     mkdir -p "$D/usr/bin" "$D/usr/sbin" \
              "$D/etc/xinetd.d" "$D/etc/$FBDIR" "$D/$VAR/data" \
              "$D/$VAR/system" "$D/$VAR/backup" \
+              mkdir -p "$D/$ULFB" \
              "$D/$COMMON_DOC/examples"
 
     copy e "$D/usr/sbin"              \
@@ -123,10 +129,12 @@ make_server () {
 
 
     # manpages
-    for u in fbtracemgr fbguard fb_lock_print firebird ;
-    do
-        dh_installman -p "$P" "debian/man/$u.1"
-    done
+    if [ -z "$NODOC" ]; then
+        for u in fbtracemgr fbguard fb_lock_print firebird ;
+        do
+            dh_installman -p "$P" "debian/man/$u.1"
+        done
+    fi
 
     install -m 0644 "debian/$P.xinetd" \
                     "$D/etc/xinetd.d/$FB_no_dots"
@@ -135,11 +143,18 @@ make_server () {
         "$S/databases.conf" \
         "$S/fbtrace.conf"
 
-    # fix databases.conf: employee.fdb should point to a database
-    # in /$VAR/data where all databases live
-    sed -i -e s,"\$(dir_sampleDb)/,/$VAR/data/", \
+    for f in databases fbtrace ; do
+        ln -s "/etc/$FBDIR/$f.conf" "$D/$ULFB/"
+    done
+
+    # fix databases.conf: Remove references to employee
+    sed -i -e'/^# Example Database/,/^employee / d' \
         "$D/etc/$FBDIR/databases.conf"
 
+    # security db SQL
+    mkdir -p "$D/usr/share/$FBDIR"
+    install -m0644 "src/dbs/security.sql" "$D/usr/share/$FBDIR/"
+
     touch "$D/$VAR/backup/no_empty"
     touch "$D/$VAR/data/no_empty"
 
@@ -168,10 +183,6 @@ make_server () {
     sed -i -e"s,firebird-classic,firebird$FB_VER-classic," \
         "$D/lib/systemd/system/firebird$FB_VER.service"
 
-    # databases
-    cp "$S/security3.fdb" \
-        "$D/$VAR/system/default-security3.fdb"
-
     copy f "$D/$COMMON_DOC/examples" debian/reindex-db
 
     doc_symlink
@@ -230,10 +241,12 @@ make_utils () {
     copy_utils
 
     # manpages
-    for u in fbstat gbak gsec isql-fb gfix gpre nbackup fbsvcmgr ;
-    do
-        dh_installman -p "$P" "debian/man/$u.1"
-    done
+    if [ -z "$NODOC" ]; then
+        for u in fbstat gbak gsec isql-fb gfix gpre nbackup fbsvcmgr ;
+        do
+            dh_installman -p "$P" "debian/man/$u.1"
+        done
+    fi
 
     doc_symlink
 }
@@ -256,7 +269,7 @@ make_common () {
     sed "s,\$(this),\$(root)/intl," "$S/intl/fbintl.conf" > "$D/etc/$FBDIR/fbintl.conf"
     copy f "$D/etc/$FBDIR/plugins.conf" "$S/plugins.conf"
 
-    install -m 0644 -o root -g root \
+    install -m 0644 \
         debian/functions.sh \
         "$D/usr/share/$P/"
 
@@ -293,7 +306,9 @@ make_dev () {
             "$D/usr/lib/$DEB_HOST_MULTIARCH/libib_util.so"
     fi
 
-    dh_installman -p "$P" debian/man/fb_config.1
+    if [ -z "$NODOC" ]; then
+        dh_installman -p "$P" debian/man/fb_config.1
+    fi
 
     doc_symlink
 }
@@ -308,6 +323,24 @@ make_examples () {
 
     mkdir -p "$D/$COMMON_DOC"
     cp -r "$S/examples" "$D/$COMMON_DOC"
+    rm -r "$D/$COMMON_DOC/examples/empbuild"
+
+    (
+        echo "-- This is a generated file"
+        echo "set sql dialect 3;"
+        echo "create database 'employee.fdb';"
+        cat "examples/empbuild/empddl.sql"
+        cat "examples/empbuild/indexoff.sql"
+        cat "examples/empbuild/empdml.sql"
+        cat "examples/empbuild/indexon.sql"
+        debian/emp_data.pl --table job --key job_code,job_grade,job_country \
+            --blob-col job_requirement \
+            < "examples/empbuild/job.inp"
+        debian/emp_data.pl --table project --key proj_id \
+            --blob-col proj_desc \
+            < "examples/empbuild/proj.inp"
+    ) > "$D/$COMMON_DOC/examples/employee.sql";
+
 
     # remove empty directories
     find "$D/$COMMON_DOC/examples" -type d -print0 \
@@ -329,8 +362,10 @@ make_doc () {
 
     mkdir -p "$D"
 
-    cp -r "$S"/* "$D/"
-    rm -r "$D/license"
+    if [ -z "$NODOC" ]; then
+        cp -r "$S"/* "$D/"
+        rm -r "$D/license"
+    fi
 
     doc_symlink
 }
@@ -340,6 +375,11 @@ make_common_doc() {
     P="$FB-common-doc"
     echo "Creating $P content"
     mkdir -p "debian/$P/$COMMON_DOC"
+
+    install -m 0644 \
+        "debian/README.Debian" \
+        "debian/$P/$COMMON_DOC/README.Debian"
+
 }
 
 umask 022
